← Back to team overview

cloud-init-dev team mailing list archive

[Merge] ~smoser/cloud-init:bug/1698669-ds-identify-fujitsu-ovf into cloud-init:master

 

Scott Moser has proposed merging ~smoser/cloud-init:bug/1698669-ds-identify-fujitsu-ovf into cloud-init:master.

Commit message:
OVF: Extend well-known labels to include OVFENV.

Fujitsu Cloud Service attaches a ovf iso transport with a label
'OVFENV'.  This seems to be a reasonable value as a label.

While the for bug 1731868 would likely fix cloud-init on fujitsu
cloud, this change will find it faster.

LP: #1698669

Requested reviews:
  cloud-init commiters (cloud-init-dev)
Related bugs:
  Bug #1698669 in cloud-init: "ds-identify does not recognize Fujitsu Cloud Service S5 as OVF"
  https://bugs.launchpad.net/cloud-init/+bug/1698669

For more details, see:
https://code.launchpad.net/~smoser/cloud-init/+git/cloud-init/+merge/336630

see commit message
-- 
Your team cloud-init commiters is requested to review the proposed merge of ~smoser/cloud-init:bug/1698669-ds-identify-fujitsu-ovf into cloud-init:master.
diff --git a/HACKING.rst b/HACKING.rst
index 93e3f42..3bb555c 100644
--- a/HACKING.rst
+++ b/HACKING.rst
@@ -16,6 +16,14 @@ Do these things once
   When prompted for 'Project contact' or 'Canonical Project Manager' enter
   'Scott Moser'.
 
+* Configure git with your email and name for commit messages.
+
+  Your name will appear in commit messages and will also be used in
+  changelogs or release notes.  Give yourself credit!::
+
+    git config user.name "Your Name"
+    git config user.email "Your Email"
+
 * Clone the upstream `repository`_ on Launchpad::
 
     git clone https://git.launchpad.net/cloud-init
diff --git a/tools/ds-identify b/tools/ds-identify
index 374c3ad..cd26824 100755
--- a/tools/ds-identify
+++ b/tools/ds-identify
@@ -664,7 +664,9 @@ is_cdrom_ovf() {
     esac
 
     # fast path known 'OVF' labels
-    [ "$label" = "OVF-TRANSPORT" -o "$label" = "ovf-transport" ] && return 0
+    case "$label" in
+        OVF-TRANSPORT|ovf-transport|OVFENV|ovfenv) return 0;;
+    esac
 
     # explicitly skip known labels of other types. rd_rdfe is azure.
     case "$label" in

Follow ups
diff --git a/tests/unittests/test_ds_identify.py b/tests/unittests/test_ds_identify.py
index ad6c5cf..31cc622 100644
--- a/tests/unittests/test_ds_identify.py
+++ b/tests/unittests/test_ds_identify.py
@@ -338,7 +338,7 @@ class TestDsIdentify(CiTestCase):
         self._test_ds_found('OVF-vmware-customization')
 
     def test_ovf_on_vmware_iso_found_by_cdrom_with_matching_fs_label(self):
         """OVF is identified when iso9660 cdrom  label has ovf-transport."""
         ovf_cdrom_by_label = copy.deepcopy(VALID_CFG['OVF'])
         # Unset matching cdrom ovf schema content
         ovf_cdrom_by_label['files']['dev/sr0'] = 'No content match'
@@ -346,10 +346,12 @@ class TestDsIdentify(CiTestCase):
             ovf_cdrom_by_label, rc=RC_NOT_FOUND, policy_dmi="disabled")
 
         # Add recognized labels
-        for valid_fs_label in ['ovf-transport', 'OVF-TRANSPORT']:
+        valid_ovf_labels = ['ovf-transport', 'OVF-TRANSPORT',
+                            "OVFENV", "ovfenv"]
+        for valid_ovf_label in valid_ovf_labels:
             ovf_cdrom_by_label['mocks'][0]['out'] = blkid_out([
                 {'DEVNAME': 'sr0', 'TYPE': 'iso9660',
-                 'LABEL': valid_fs_label}])
+                 'LABEL': valid_ovf_label}])
             self._check_via_dict(
                 ovf_cdrom_by_label, rc=RC_FOUND, dslist=['OVF', DS_NONE])
 
@@ -338,7 +338,7 @@ class TestDsIdentify(CiTestCase):
 
     def test_ovf_on_vmware_iso_found_by_cdrom_with_matching_fs_label(self):
-        """OVF is identified when iso9660 cdrom  label has ovf-transport."""
+        """OVF is identified by well-known iso9660 labels."""
         ovf_cdrom_by_label = copy.deepcopy(VALID_CFG['OVF'])
         # Unset matching cdrom ovf schema content